@@ -1,7 +1,7 @@
 ;; The SWIG modules have "passive" Linkage, i.e., they don't generate
 ;; Guile modules (namespaces) but simply put all the bindings into the
 ;; current module.  That's enough for such a simple test.
-(dynamic-call "scm_init_test_module" (dynamic-link "./liblist_vector.so"))
+(dynamic-call "scm_init_list_vector_module" (dynamic-link "./liblist_vector.so"))
 
 (define-macro (check form)
   `(if (not ,form)
@@ -17,8 +17,8 @@
 (check (equal? (one-to-seven-list2) '(1 2 3 4 5 6 7)))
 (check (equal? (one-to-seven-vector2) #(1 2 3 4 5 6 7)))
 
-(check (= (sum-lists '(1 2 3) '(4 5 6) '(7 8 9)) 45))
-(check (= (sum-lists2 '(1 2 3) '(4 5 6) '(7 8 9)) 45))
+(check (= (sum-lists '(1 2 3) '(4 5 6) '(7 8 9)) 45.0))
+(check (= (sum-lists2 '(1 2 3) '(4 5 6) '(7 8 9)) 45.0))
 (check (equal? (call-with-values produce-lists list)
 	       '(#(0 1 2 3 4)
 		 #(0 1 4 9 16)
